@@ -34,6 +34,8 @@ get.init.deltas<-function(model, control){
     control[["group.deltas"]]<-diag(group.deltas.scale*control[["group.deltas"]]*2/(1+nterms),nrow=nterms)
   }
 
+  control[["group.acf.adjust"]]<-rep(1,nrow(control[["group.deltas"]]))
+  
   control
 }
 
@@ -44,16 +46,27 @@ get.sample.deltas<-function(model,sample,control){
   Z.rate<-0
   beta.rate<-0
   cov.beta.ext<-0
+
+  acf.adjust<-rep(1,length(control[["group.acf.adjust"]]))
   
   for(thread in 1:control[["threads"]]){
     sample<-samples[[thread]]
     use.draws<-ceiling(length(sample)*control[["pilot.discard.first"]]):(length(sample))
     Z.rate<-if(!is.null(sample[["Z.rate"]]))Z.rate+mean(sample[["Z.rate"]][use.draws])/control[["threads"]] else 0.5
     beta.rate<-beta.rate+mean(sample[["beta.rate"]][use.draws])/control[["threads"]]
-    ## Note that this only measures the covariances _within_ the thread.
-    cov.beta.ext<-cov.beta.ext+cov.beta.ext(model,sample[use.draws])/control[["threads"]]
+
+    beta.ext<-get.beta.ext(model,sample)
+    beta.ext.ar.eff<-1/(1-apply(beta.ext,2,function(b) ar(b,order.max=1,aic=FALSE)$ar))
+    acf.adjust<-acf.adjust*beta.ext.ar.eff/exp(mean(log(beta.ext.ar.eff)))
+
+    ## Note that this only measures the covariances _within_ the thread.    
+    cov.beta.ext<-cov.beta.ext+cov(beta.ext)/control[["threads"]]
   }
 
+  control[["group.acf.adjust"]]<-control[["group.acf.adjust"]]*acf.adjust^(1/control[["threads"]])
+  
+  cov.beta.ext<-t(cov.beta.ext*control[["group.acf.adjust"]])*control[["group.acf.adjust"]]
+
   if(model[["d"]]) control[["Z.delta"]]<-control[["Z.delta"]]*Z.rate/control[["target.acc.rate"]]
   if(model[["sender"]] || model[["receiver"]] || model[["sociality"]]) control[["RE.delta"]]<-control[["RE.delta"]]*Z.rate/control[["target.acc.rate"]]
   control[["pilot.factor"]]<-control[["pilot.factor"]]*beta.rate/control[["target.acc.rate"]]
@@ -65,16 +78,16 @@ get.sample.deltas<-function(model,sample,control){
 }
 
 ## Compute the empirical covariance of coefficients, latent scale, and random effect means.
-cov.beta.ext<-function(model,sample){
+get.beta.ext<-function(model,sample){
   n<-network.size(model[["Yg"]])
   ## Construct the "extended" beta: not just the coefficients, but also the scale of latent space and all random effects.
-  beta.ext<-cbind(if(model[["p"]]) sample[["beta"]], # covariate coefs
-                  if(model[["d"]]) log(apply(sqrt(apply(sample[["Z"]]^2,1:2,sum)),1,mean)), # scale of Z
-                  if(model[["sender"]]) tcrossprod(sample[["sender"]],model[["beta.eff.sender"]])/n, # sender eff.
-                  if(model[["receiver"]]) tcrossprod(sample[["receiver"]],model[["beta.eff.receiver"]])/n, # receiver eff.
-                  if(model[["sociality"]]) tcrossprod(sample[["sociality"]],model[["beta.eff.sociality"]]/n) # sociality eff.
-                  )
-  cov(beta.ext)
+  betas<-cbind(if(model[["p"]]) sample[["beta"]], # covariate coefs
+                if(model[["d"]]) log(apply(sqrt(apply(sample[["Z"]]^2,1:2,sum)),1,mean)), # scale of Z
+                if(model[["sender"]]) tcrossprod(sample[["sender"]],model[["beta.eff.sender"]])/n, # sender eff.
+                if(model[["receiver"]]) tcrossprod(sample[["receiver"]],model[["beta.eff.receiver"]])/n, # receiver eff.
+                if(model[["sociality"]]) tcrossprod(sample[["sociality"]],model[["beta.eff.sociality"]]/n) # sociality eff.
+        )
+  sweep(betas,2,apply(betas,2,mean))
 }
 
 backoff.check<-function(model,sample,control){
@@ -106,7 +119,7 @@ backoff.check<-function(model,sample,control){
     backoff<-+1
   }
   if(backoff){
-    backoff.str<-paste("Pilot run had catastrophically",if(backoff<0) "low" else "high", "acceptance rates, and will be redone with",if(backoff<0) "smaller" else "bigger", "proposal variances. If you see this message several times in a row, it may be due to too much variability in acceptance rate, an unknown bug or a posterior distribution the algorithm cannot properly explore. Increase burn-in period, and if that does not help, please report it.",sep=" ")
+    backoff.str<-paste("Backing off: too",if(backoff<0) "few" else "many", "acceptances. If you see this message several times in a row, use a longer burnin.",sep=" ")
     if(control[["verbose"]]) cat(paste(backoff.str,"\n",sep=""))
     else warning(backoff.str)
   }
